@@ -49,6 +49,10 @@ class DataFreeThrow(FreeThrow, DataEnhancedPbpItem):
     def is_technical_ft(self):
         return " Technical" in self.description
 
+    @property
+    def is_flagrant_ft(self):
+        return " Flagrant" in self.description
+
     @property
     def is_ft_1pt(self):
         """
